[Libreoffice-commits] core.git: 11 commits - cui/uiconfig dbaccess/inc dbaccess/source dbaccess/uiconfig dbaccess/UIConfig_dbaccess.mk desktop/source filter/source sc/inc sc/qa sc/source

Caolán McNamara caolanm at redhat.com
Wed Jan 29 02:57:48 PST 2014


 cui/uiconfig/ui/acorreplacepage.ui          |  178 ++++++++++++++--------------
 dbaccess/UIConfig_dbaccess.mk               |    1 
 dbaccess/inc/dbaccess_helpid.hrc            |    2 
 dbaccess/source/ui/dlg/advancedsettings.cxx |    1 
 dbaccess/source/ui/dlg/dbadmin.cxx          |   21 +--
 dbaccess/source/ui/dlg/dbadmin.src          |   17 --
 dbaccess/source/ui/dlg/dbwizsetup.cxx       |    5 
 dbaccess/source/ui/inc/dbu_resource.hrc     |    1 
 dbaccess/uiconfig/ui/admindialog.ui         |  106 ++++++++++++++++
 desktop/source/lib/shim.c                   |    1 
 filter/source/msfilter/svdfppt.cxx          |  140 +++++++++++-----------
 sc/inc/shapeuno.hxx                         |    3 
 sc/inc/viewuno.hxx                          |    7 -
 sc/qa/unit/ucalc_formula.cxx                |    4 
 sc/source/ui/unoobj/shapeuno.cxx            |    4 
 sc/source/ui/unoobj/viewuno.cxx             |    6 
 16 files changed, 298 insertions(+), 199 deletions(-)

New commits:
commit 8d464a7423ac8f3eb30eb80a0e5041989a4cc2da
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Wed Jan 29 10:51:21 2014 +0000

    Resolves: fdo#74070 make replace and with fields the same width
    
    Change-Id: I2fbd7d6ed4e657660334a572768f12cbba1d75e2

diff --git a/cui/uiconfig/ui/acorreplacepage.ui b/cui/uiconfig/ui/acorreplacepage.ui
index 199269f..2f7c6f8 100644
--- a/cui/uiconfig/ui/acorreplacepage.ui
+++ b/cui/uiconfig/ui/acorreplacepage.ui
@@ -1,7 +1,8 @@
 <?xml version="1.0" encoding="UTF-8"?>
+<!-- Generated with glade 3.16.0 on Wed Jan 29 10:50:29 2014 -->
 <interface>
-  <!-- interface-requires LibreOffice 1.0 -->
   <!-- interface-requires gtk+ 3.0 -->
+  <!-- interface-requires LibreOffice 1.0 -->
   <object class="GtkGrid" id="AcorReplacePage">
     <property name="visible">True</property>
     <property name="can_focus">False</property>
@@ -11,86 +12,6 @@
     <property name="row_spacing">6</property>
     <property name="column_spacing">12</property>
     <child>
-      <object class="GtkLabel" id="label1">
-        <property name="visible">True</property>
-        <property name="can_focus">False</property>
-        <property name="xalign">0</property>
-        <property name="label" translatable="yes">Repla_ce</property>
-        <property name="use_underline">True</property>
-        <property name="mnemonic_widget">origtext</property>
-      </object>
-      <packing>
-        <property name="left_attach">0</property>
-        <property name="top_attach">0</property>
-        <property name="width">1</property>
-        <property name="height">1</property>
-      </packing>
-    </child>
-    <child>
-      <object class="GtkLabel" id="label2">
-        <property name="visible">True</property>
-        <property name="can_focus">False</property>
-        <property name="xalign">0</property>
-        <property name="label" translatable="yes">_With:</property>
-        <property name="use_underline">True</property>
-        <property name="mnemonic_widget">newtext</property>
-      </object>
-      <packing>
-        <property name="left_attach">1</property>
-        <property name="top_attach">0</property>
-        <property name="width">1</property>
-        <property name="height">1</property>
-      </packing>
-    </child>
-    <child>
-      <object class="GtkCheckButton" id="textonly">
-        <property name="label" translatable="yes">_Text only</property>
-        <property name="visible">True</property>
-        <property name="can_focus">True</property>
-        <property name="receives_default">False</property>
-        <property name="halign">end</property>
-        <property name="use_underline">True</property>
-        <property name="xalign">0</property>
-        <property name="draw_indicator">True</property>
-      </object>
-      <packing>
-        <property name="left_attach">2</property>
-        <property name="top_attach">0</property>
-        <property name="width">1</property>
-        <property name="height">1</property>
-      </packing>
-    </child>
-    <child>
-      <object class="cuilo-AutoCorrEdit" id="origtext">
-        <property name="visible">True</property>
-        <property name="can_focus">True</property>
-        <property name="hexpand">True</property>
-        <property name="invisible_char">●</property>
-        <property name="width_chars">20</property>
-      </object>
-      <packing>
-        <property name="left_attach">0</property>
-        <property name="top_attach">1</property>
-        <property name="width">1</property>
-        <property name="height">1</property>
-      </packing>
-    </child>
-    <child>
-      <object class="cuilo-AutoCorrEdit" id="newtext">
-        <property name="visible">True</property>
-        <property name="can_focus">True</property>
-        <property name="hexpand">True</property>
-        <property name="invisible_char">●</property>
-        <property name="width_chars">30</property>
-      </object>
-      <packing>
-        <property name="left_attach">1</property>
-        <property name="top_attach">1</property>
-        <property name="width">2</property>
-        <property name="height">1</property>
-      </packing>
-    </child>
-    <child>
       <object class="GtkButtonBox" id="buttonbox1">
         <property name="visible">True</property>
         <property name="can_focus">False</property>
@@ -143,7 +64,7 @@
         </child>
       </object>
       <packing>
-        <property name="left_attach">3</property>
+        <property name="left_attach">2</property>
         <property name="top_attach">1</property>
         <property name="width">1</property>
         <property name="height">2</property>
@@ -160,7 +81,98 @@
       <packing>
         <property name="left_attach">0</property>
         <property name="top_attach">2</property>
-        <property name="width">3</property>
+        <property name="width">2</property>
+        <property name="height">1</property>
+      </packing>
+    </child>
+    <child>
+      <object class="cuilo-AutoCorrEdit" id="newtext">
+        <property name="visible">True</property>
+        <property name="can_focus">True</property>
+        <property name="hexpand">True</property>
+        <property name="width_chars">25</property>
+      </object>
+      <packing>
+        <property name="left_attach">1</property>
+        <property name="top_attach">1</property>
+        <property name="width">1</property>
+        <property name="height">1</property>
+      </packing>
+    </child>
+    <child>
+      <object class="cuilo-AutoCorrEdit" id="origtext">
+        <property name="visible">True</property>
+        <property name="can_focus">True</property>
+        <property name="hexpand">True</property>
+        <property name="width_chars">25</property>
+      </object>
+      <packing>
+        <property name="left_attach">0</property>
+        <property name="top_attach">1</property>
+        <property name="width">1</property>
+        <property name="height">1</property>
+      </packing>
+    </child>
+    <child>
+      <object class="GtkLabel" id="label1">
+        <property name="visible">True</property>
+        <property name="can_focus">False</property>
+        <property name="xalign">0</property>
+        <property name="label" translatable="yes">Repla_ce</property>
+        <property name="use_underline">True</property>
+        <property name="mnemonic_widget">origtext</property>
+      </object>
+      <packing>
+        <property name="left_attach">0</property>
+        <property name="top_attach">0</property>
+        <property name="width">1</property>
+        <property name="height">1</property>
+      </packing>
+    </child>
+    <child>
+      <object class="GtkGrid" id="grid1">
+        <property name="visible">True</property>
+        <property name="can_focus">False</property>
+        <child>
+          <object class="GtkLabel" id="label2">
+            <property name="visible">True</property>
+            <property name="can_focus">False</property>
+            <property name="xalign">0</property>
+            <property name="label" translatable="yes">_With:</property>
+            <property name="use_underline">True</property>
+            <property name="mnemonic_widget">newtext</property>
+          </object>
+          <packing>
+            <property name="left_attach">0</property>
+            <property name="top_attach">0</property>
+            <property name="width">1</property>
+            <property name="height">1</property>
+          </packing>
+        </child>
+        <child>
+          <object class="GtkCheckButton" id="textonly">
+            <property name="label" translatable="yes">_Text only</property>
+            <property name="visible">True</property>
+            <property name="can_focus">True</property>
+            <property name="receives_default">False</property>
+            <property name="halign">end</property>
+            <property name="hexpand">True</property>
+            <property name="use_underline">True</property>
+            <property name="xalign">0</property>
+            <property name="draw_indicator">True</property>
+          </object>
+          <packing>
+            <property name="left_attach">1</property>
+            <property name="top_attach">0</property>
+            <property name="width">1</property>
+            <property name="height">1</property>
+          </packing>
+        </child>
+      </object>
+      <packing>
+        <property name="left_attach">1</property>
+        <property name="top_attach">0</property>
+        <property name="width">1</property>
         <property name="height">1</property>
       </packing>
     </child>
commit 6db0345af49dca17274f5d4a9a1dcdf6cf81fe60
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Wed Jan 29 10:37:12 2014 +0000

    coverity#1158317 Uncaught exception
    
    Change-Id: Ic725ffdc2041325b951b4790c2166d25053f7df2

diff --git a/sc/inc/viewuno.hxx b/sc/inc/viewuno.hxx
index 7cf2f38..84529dc 100644
--- a/sc/inc/viewuno.hxx
+++ b/sc/inc/viewuno.hxx
@@ -333,7 +333,9 @@ public:
     virtual sal_Bool SAL_CALL getIsWindowSplit() throw(::com::sun::star::uno::RuntimeException);
     virtual sal_Int32 SAL_CALL getSplitHorizontal() throw(::com::sun::star::uno::RuntimeException);
     virtual sal_Int32 SAL_CALL getSplitVertical() throw(::com::sun::star::uno::RuntimeException);
-    virtual sal_Int32 SAL_CALL getSplitColumn() throw(::com::sun::star::uno::RuntimeException);
+    virtual sal_Int32 SAL_CALL getSplitColumn()
+        throw(::com::sun::star::uno::RuntimeException,
+              std::exception);
     virtual sal_Int32 SAL_CALL getSplitRow()
         throw(::com::sun::star::uno::RuntimeException, std::exception);
     virtual void SAL_CALL   splitAtPosition( sal_Int32 nPixelX, sal_Int32 nPixelY )
diff --git a/sc/source/ui/unoobj/viewuno.cxx b/sc/source/ui/unoobj/viewuno.cxx
index deb16a8..3d596c5 100644
--- a/sc/source/ui/unoobj/viewuno.cxx
+++ b/sc/source/ui/unoobj/viewuno.cxx
@@ -1641,7 +1641,8 @@ sal_Int32 SAL_CALL ScTabViewObj::getSplitVertical() throw(uno::RuntimeException)
     return 0;
 }
 
-sal_Int32 SAL_CALL ScTabViewObj::getSplitColumn() throw(uno::RuntimeException)
+sal_Int32 SAL_CALL ScTabViewObj::getSplitColumn()
+    throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     ScTabViewShell* pViewSh = GetViewShell();
commit 5bf532fa4d54fe5707f381568da2f0a666487a66
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Wed Jan 29 10:18:41 2014 +0000

    coverity#1158318 Uncaught exception
    
    Change-Id: Ia0bfd736262e9c22b18c094defee0779e8ce6515

diff --git a/sc/inc/viewuno.hxx b/sc/inc/viewuno.hxx
index e6883f8..7cf2f38 100644
--- a/sc/inc/viewuno.hxx
+++ b/sc/inc/viewuno.hxx
@@ -236,7 +236,8 @@ public:
                                       ::com::sun::star::uno::RuntimeException,
                                       std::exception);
     virtual ::com::sun::star::uno::Any SAL_CALL getSelection()
-                                throw(::com::sun::star::uno::RuntimeException);
+                                throw(::com::sun::star::uno::RuntimeException,
+                                      std::exception);
     virtual void SAL_CALL   addSelectionChangeListener( const ::com::sun::star::uno::Reference<
                                 ::com::sun::star::view::XSelectionChangeListener >& xListener )
                                     throw(::com::sun::star::uno::RuntimeException);
diff --git a/sc/source/ui/unoobj/viewuno.cxx b/sc/source/ui/unoobj/viewuno.cxx
index 1f0428e..deb16a8 100644
--- a/sc/source/ui/unoobj/viewuno.cxx
+++ b/sc/source/ui/unoobj/viewuno.cxx
@@ -879,7 +879,8 @@ sal_Bool SAL_CALL ScTabViewObj::select( const uno::Any& aSelection )
     return bRet;
 }
 
-uno::Any SAL_CALL ScTabViewObj::getSelection() throw(uno::RuntimeException)
+uno::Any SAL_CALL ScTabViewObj::getSelection()
+    throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     ScTabViewShell* pViewSh = GetViewShell();
commit 037a639c1b5aca55bc07515c6e1da7c9b55f852f
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Wed Jan 29 10:16:45 2014 +0000

    coverity#1158320 Uncaught exception
    
    Change-Id: If68a965d1c9da89c28fca67019ef14e05ab9722e

diff --git a/sc/inc/shapeuno.hxx b/sc/inc/shapeuno.hxx
index 73a0f32..a57e9df 100644
--- a/sc/inc/shapeuno.hxx
+++ b/sc/inc/shapeuno.hxx
@@ -114,7 +114,8 @@ public:
                                     const OUString& PropertyName )
                                 throw(::com::sun::star::beans::UnknownPropertyException,
                                     ::com::sun::star::lang::WrappedTargetException,
-                                    ::com::sun::star::uno::RuntimeException);
+                                    ::com::sun::star::uno::RuntimeException,
+                                    std::exception);
     virtual void SAL_CALL   addPropertyChangeListener( const OUString& aPropertyName,
                                     const ::com::sun::star::uno::Reference<
                                         ::com::sun::star::beans::XPropertyChangeListener >& xListener )
diff --git a/sc/source/ui/unoobj/shapeuno.cxx b/sc/source/ui/unoobj/shapeuno.cxx
index 1ed1198..c233d86 100644
--- a/sc/source/ui/unoobj/shapeuno.cxx
+++ b/sc/source/ui/unoobj/shapeuno.cxx
@@ -666,8 +666,8 @@ void SAL_CALL ScShapeObj::setPropertyValue(const OUString& aPropertyName, const
 }
 
 uno::Any SAL_CALL ScShapeObj::getPropertyValue( const OUString& aPropertyName )
-                throw(beans::UnknownPropertyException, lang::WrappedTargetException,
-                        uno::RuntimeException)
+    throw(beans::UnknownPropertyException, lang::WrappedTargetException,
+          uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     OUString aNameString = aPropertyName;
commit fe89615fd255331f8a27c8eb0c5a18319c4a806c
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Wed Jan 29 10:07:43 2014 +0000

    coverity#1000696 Out-of-bounds access
    
    Change-Id: I4e69c7f5e45882238c4cc27244f38b81c87780e2

diff --git a/filter/source/msfilter/svdfppt.cxx b/filter/source/msfilter/svdfppt.cxx
index 6bc4cd6..18e380d 100644
--- a/filter/source/msfilter/svdfppt.cxx
+++ b/filter/source/msfilter/svdfppt.cxx
@@ -5321,7 +5321,7 @@ PPTPortionObj::PPTPortionObj( const PPTCharPropSet& rCharPropSet, const PPTStyle
     PPTCharPropSet  ( rCharPropSet ),
     mrStyleSheet    ( rStyleSheet ),
     mnInstance      ( nInstance ),
-    mnDepth         ( nDepth )
+    mnDepth         ( ( nDepth > 4 ) ? 4 : nDepth )
 {
 }
 
commit 19aa235feb3e301ff3a20e102754b6ee7c7b63fc
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Wed Jan 29 10:00:29 2014 +0000

    nRetValue was a reference, nRetValue->rRetValue
    
    Change-Id: I0516bc22274a3bdba54246613c9925d3f2a67c44

diff --git a/filter/source/msfilter/svdfppt.cxx b/filter/source/msfilter/svdfppt.cxx
index ad0ecba..6bc4cd6 100644
--- a/filter/source/msfilter/svdfppt.cxx
+++ b/filter/source/msfilter/svdfppt.cxx
@@ -5354,10 +5354,10 @@ sal_Bool PPTPortionObj::HasTabulator()
     return bRetValue;
 }
 
-sal_Bool PPTPortionObj::GetAttrib( sal_uInt32 nAttr, sal_uInt32& nRetValue, sal_uInt32 nDestinationInstance ) const
+sal_Bool PPTPortionObj::GetAttrib( sal_uInt32 nAttr, sal_uInt32& rRetValue, sal_uInt32 nDestinationInstance ) const
 {
     sal_uInt32  nMask = 1 << nAttr;
-    nRetValue = 0;
+    rRetValue = 0;
 
     sal_uInt32 bIsHardAttribute = ( ( pCharSet->mnAttrSet & nMask ) != 0 ) ? 1 : 0;
 
@@ -5371,22 +5371,22 @@ sal_Bool PPTPortionObj::GetAttrib( sal_uInt32 nAttr, sal_uInt32& nRetValue, sal_
             case PPT_CharAttr_Shadow :
             case PPT_CharAttr_Strikeout :
             case PPT_CharAttr_Embossed :
-                nRetValue = ( pCharSet->mnFlags & nMask ) ? 1 : 0;
+                rRetValue = ( pCharSet->mnFlags & nMask ) ? 1 : 0;
             break;
             case PPT_CharAttr_Font :
-                nRetValue = pCharSet->mnFont;
+                rRetValue = pCharSet->mnFont;
             break;
             case PPT_CharAttr_AsianOrComplexFont :
-                nRetValue = pCharSet->mnAsianOrComplexFont;
+                rRetValue = pCharSet->mnAsianOrComplexFont;
             break;
             case PPT_CharAttr_FontHeight :
-                nRetValue = pCharSet->mnFontHeight;
+                rRetValue = pCharSet->mnFontHeight;
             break;
             case PPT_CharAttr_FontColor :
-                nRetValue = pCharSet->mnColor;
+                rRetValue = pCharSet->mnColor;
             break;
             case PPT_CharAttr_Escapement :
-                nRetValue = pCharSet->mnEscapement;
+                rRetValue = pCharSet->mnEscapement;
             break;
             default :
                 OSL_FAIL( "SJ:PPTPortionObj::GetAttrib ( hard attribute does not exist )" );
@@ -5410,47 +5410,47 @@ sal_Bool PPTPortionObj::GetAttrib( sal_uInt32 nAttr, sal_uInt32& nRetValue, sal_
             case PPT_CharAttr_Strikeout :
             case PPT_CharAttr_Embossed :
             {
-                nRetValue = ( rCharLevel.mnFlags & nMask ) ? 1 : 0;
+                rRetValue = ( rCharLevel.mnFlags & nMask ) ? 1 : 0;
                 if ( pCharLevel )
                 {
                     sal_uInt32 nTmp = ( pCharLevel->mnFlags & nMask ) ? 1 : 0;
-                    if ( nRetValue != nTmp )
+                    if ( rRetValue != nTmp )
                         bIsHardAttribute = 1;
                 }
             }
             break;
             case PPT_CharAttr_Font :
             {
-                nRetValue = rCharLevel.mnFont;
-                if ( pCharLevel && ( nRetValue != pCharLevel->mnFont ) )
+                rRetValue = rCharLevel.mnFont;
+                if ( pCharLevel && ( rRetValue != pCharLevel->mnFont ) )
                     bIsHardAttribute = 1;
             }
             break;
             case PPT_CharAttr_AsianOrComplexFont :
             {
-                nRetValue = rCharLevel.mnAsianOrComplexFont;
-                if ( pCharLevel && ( nRetValue != pCharLevel->mnAsianOrComplexFont ) )
+                rRetValue = rCharLevel.mnAsianOrComplexFont;
+                if ( pCharLevel && ( rRetValue != pCharLevel->mnAsianOrComplexFont ) )
                     bIsHardAttribute = 1;
             }
             break;
             case PPT_CharAttr_FontHeight :
             {
-                nRetValue = rCharLevel.mnFontHeight;
-                if ( pCharLevel && ( nRetValue != pCharLevel->mnFontHeight ) )
+                rRetValue = rCharLevel.mnFontHeight;
+                if ( pCharLevel && ( rRetValue != pCharLevel->mnFontHeight ) )
                     bIsHardAttribute = 1;
             }
             break;
             case PPT_CharAttr_FontColor :
             {
-                nRetValue = rCharLevel.mnFontColor;
-                if ( pCharLevel && ( nRetValue != pCharLevel->mnFontColor ) )
+                rRetValue = rCharLevel.mnFontColor;
+                if ( pCharLevel && ( rRetValue != pCharLevel->mnFontColor ) )
                     bIsHardAttribute = 1;
             }
             break;
             case PPT_CharAttr_Escapement :
             {
-                nRetValue = rCharLevel.mnEscapement;
-                if ( pCharLevel && ( nRetValue != pCharLevel->mnEscapement ) )
+                rRetValue = rCharLevel.mnEscapement;
+                if ( pCharLevel && ( rRetValue != pCharLevel->mnEscapement ) )
                     bIsHardAttribute = 1;
             }
             break;
@@ -5775,10 +5775,10 @@ void PPTParagraphObj::UpdateBulletRelSize( sal_uInt32& nBulletRelSize ) const
     }
 }
 
-sal_Bool PPTParagraphObj::GetAttrib( sal_uInt32 nAttr, sal_uInt32& nRetValue, sal_uInt32 nDestinationInstance )
+sal_Bool PPTParagraphObj::GetAttrib( sal_uInt32 nAttr, sal_uInt32& rRetValue, sal_uInt32 nDestinationInstance )
 {
     sal_uInt32  nMask = 1 << nAttr;
-    nRetValue = 0;
+    rRetValue = 0;
 
     if ( nAttr > 21 )
     {
@@ -5799,20 +5799,20 @@ sal_Bool PPTParagraphObj::GetAttrib( sal_uInt32 nAttr, sal_uInt32& nRetValue, sa
                 bHardBulletColor = ( mrStyleSheet.mpParaSheet[ mnInstance ]->maParaLevel[ pParaSet->mnDepth ].mnBuFlags
                                         & ( 1 << PPT_ParaAttr_BuHardColor ) ) != 0;
             if ( bHardBulletColor )
-                nRetValue = pParaSet->mnBulletColor;
+                rRetValue = pParaSet->mnBulletColor;
             else
             {
-                nRetValue = PPT_COLSCHEME_TEXT_UND_ZEILEN;
+                rRetValue = PPT_COLSCHEME_TEXT_UND_ZEILEN;
                 if ((nDestinationInstance != 0xffffffff) && !m_PortionList.empty())
                 {
                     PPTPortionObj const& rPortion = m_PortionList.front();
                     if (rPortion.pCharSet->mnAttrSet & (1 << PPT_CharAttr_FontColor))
                     {
-                        nRetValue = rPortion.pCharSet->mnColor;
+                        rRetValue = rPortion.pCharSet->mnColor;
                     }
                     else
                     {
-                        nRetValue = mrStyleSheet.mpCharSheet[ nDestinationInstance ]->maCharLevel[ pParaSet->mnDepth ].mnFontColor;
+                        rRetValue = mrStyleSheet.mpCharSheet[ nDestinationInstance ]->maCharLevel[ pParaSet->mnDepth ].mnFontColor;
                     }
                 }
             }
@@ -5826,27 +5826,27 @@ sal_Bool PPTParagraphObj::GetAttrib( sal_uInt32 nAttr, sal_uInt32& nRetValue, sa
                 bHardBuFont = ( mrStyleSheet.mpParaSheet[ mnInstance ]->maParaLevel[ pParaSet->mnDepth ].mnBuFlags
                                         & ( 1 << PPT_ParaAttr_BuHardFont ) ) != 0;
             if ( bHardBuFont )
-                nRetValue = pParaSet->mpArry[ PPT_ParaAttr_BulletFont ];
+                rRetValue = pParaSet->mpArry[ PPT_ParaAttr_BulletFont ];
             else
             {
                 // it is the font used which assigned to the first character of the following text
-                nRetValue = 0;
+                rRetValue = 0;
                 if ((nDestinationInstance != 0xffffffff) && !m_PortionList.empty())
                 {
                     PPTPortionObj const& rPortion = m_PortionList.front();
                     if (rPortion.pCharSet->mnAttrSet & ( 1 << PPT_CharAttr_Font ) )
                     {
-                        nRetValue = rPortion.pCharSet->mnFont;
+                        rRetValue = rPortion.pCharSet->mnFont;
                     }
                     else
                     {
-                        nRetValue = mrStyleSheet.mpCharSheet[ nDestinationInstance ]->maCharLevel[ pParaSet->mnDepth ].mnFont;
+                        rRetValue = mrStyleSheet.mpCharSheet[ nDestinationInstance ]->maCharLevel[ pParaSet->mnDepth ].mnFont;
                     }
                 }
             }
         }
         else
-            nRetValue = pParaSet->mpArry[ nAttr ];
+            rRetValue = pParaSet->mpArry[ nAttr ];
     }
     else
     {
@@ -5862,10 +5862,10 @@ sal_Bool PPTParagraphObj::GetAttrib( sal_uInt32 nAttr, sal_uInt32& nRetValue, sa
         {
             case PPT_ParaAttr_BulletOn :
             {
-                nRetValue = rParaLevel.mnBuFlags & ( 1 << PPT_ParaAttr_BulletOn );
+                rRetValue = rParaLevel.mnBuFlags & ( 1 << PPT_ParaAttr_BulletOn );
                 if ( pParaLevel )
                 {
-                    if ( nRetValue != ( (sal_uInt32)pParaLevel->mnBuFlags & ( 1 << PPT_ParaAttr_BulletOn ) ) )
+                    if ( rRetValue != ( (sal_uInt32)pParaLevel->mnBuFlags & ( 1 << PPT_ParaAttr_BulletOn ) ) )
                         bIsHardAttribute = 1;
                 }
             }
@@ -5877,8 +5877,8 @@ sal_Bool PPTParagraphObj::GetAttrib( sal_uInt32 nAttr, sal_uInt32& nRetValue, sa
             break;
             case PPT_ParaAttr_BulletChar :
             {
-                nRetValue = rParaLevel.mnBulletChar;
-                if ( pParaLevel && ( nRetValue != pParaLevel->mnBulletChar ) )
+                rRetValue = rParaLevel.mnBulletChar;
+                if ( pParaLevel && ( rRetValue != pParaLevel->mnBulletChar ) )
                     bIsHardAttribute = 1;
             }
             break;
@@ -5891,8 +5891,8 @@ sal_Bool PPTParagraphObj::GetAttrib( sal_uInt32 nAttr, sal_uInt32& nRetValue, sa
                     bHardBuFont = ( rParaLevel.mnBuFlags & ( 1 << PPT_ParaAttr_BuHardFont ) ) != 0;
                 if ( bHardBuFont )
                 {
-                    nRetValue = rParaLevel.mnBulletFont;
-                    if ( pParaLevel && ( nRetValue != pParaLevel->mnBulletFont ) )
+                    rRetValue = rParaLevel.mnBulletFont;
+                    if ( pParaLevel && ( rRetValue != pParaLevel->mnBulletFont ) )
                         bIsHardAttribute = 1;
                 }
                 else
@@ -5901,11 +5901,11 @@ sal_Bool PPTParagraphObj::GetAttrib( sal_uInt32 nAttr, sal_uInt32& nRetValue, sa
                     {
                         PPTPortionObj const& rPortion = m_PortionList.front();
                         bIsHardAttribute = rPortion.GetAttrib(
-                            PPT_CharAttr_Font, nRetValue, nDestinationInstance);
+                            PPT_CharAttr_Font, rRetValue, nDestinationInstance);
                     }
                     else
                     {
-                        nRetValue = mrStyleSheet.mpCharSheet[ mnInstance ]->maCharLevel[ pParaSet->mnDepth ].mnFont;
+                        rRetValue = mrStyleSheet.mpCharSheet[ mnInstance ]->maCharLevel[ pParaSet->mnDepth ].mnFont;
                         bIsHardAttribute = 1;
                     }
                 }
@@ -5913,8 +5913,8 @@ sal_Bool PPTParagraphObj::GetAttrib( sal_uInt32 nAttr, sal_uInt32& nRetValue, sa
             break;
             case PPT_ParaAttr_BulletHeight :
             {
-                nRetValue = rParaLevel.mnBulletHeight;
-                if ( pParaLevel && ( nRetValue != pParaLevel->mnBulletHeight ) )
+                rRetValue = rParaLevel.mnBulletHeight;
+                if ( pParaLevel && ( rRetValue != pParaLevel->mnBulletHeight ) )
                     bIsHardAttribute = 1;
             }
             break;
@@ -5927,8 +5927,8 @@ sal_Bool PPTParagraphObj::GetAttrib( sal_uInt32 nAttr, sal_uInt32& nRetValue, sa
                     bHardBulletColor = ( rParaLevel.mnBuFlags & ( 1 << PPT_ParaAttr_BuHardColor ) ) != 0;
                 if ( bHardBulletColor )
                 {
-                    nRetValue = rParaLevel.mnBulletColor;
-                    if ( pParaLevel && ( nRetValue != pParaLevel->mnBulletColor ) )
+                    rRetValue = rParaLevel.mnBulletColor;
+                    if ( pParaLevel && ( rRetValue != pParaLevel->mnBulletColor ) )
                         bIsHardAttribute = 1;
                 }
                 else
@@ -5939,19 +5939,19 @@ sal_Bool PPTParagraphObj::GetAttrib( sal_uInt32 nAttr, sal_uInt32& nRetValue, sa
                         if (rPortion.mbIsHyperlink )
                         {
                             if( rPortion.mbHardHylinkOrigColor )
-                                nRetValue = rPortion.mnHylinkOrigColor;
+                                rRetValue = rPortion.mnHylinkOrigColor;
                             else
-                                nRetValue = mrStyleSheet.mpCharSheet[ mnInstance ]->maCharLevel[ pParaSet->mnDepth ].mnFontColor;
+                                rRetValue = mrStyleSheet.mpCharSheet[ mnInstance ]->maCharLevel[ pParaSet->mnDepth ].mnFontColor;
                             bIsHardAttribute = sal_True;
                         }
                         else
                         {
-                            bIsHardAttribute = rPortion.GetAttrib( PPT_CharAttr_FontColor, nRetValue, nDestinationInstance );
+                            bIsHardAttribute = rPortion.GetAttrib( PPT_CharAttr_FontColor, rRetValue, nDestinationInstance );
                         }
                     }
                     else
                     {
-                        nRetValue = mrStyleSheet.mpCharSheet[ mnInstance ]->maCharLevel[ pParaSet->mnDepth ].mnFontColor;
+                        rRetValue = mrStyleSheet.mpCharSheet[ mnInstance ]->maCharLevel[ pParaSet->mnDepth ].mnFontColor;
                         bIsHardAttribute = 1;
                     }
                 }
@@ -5959,78 +5959,78 @@ sal_Bool PPTParagraphObj::GetAttrib( sal_uInt32 nAttr, sal_uInt32& nRetValue, sa
             break;
             case PPT_ParaAttr_Adjust :
             {
-                nRetValue = rParaLevel.mnAdjust;
-                if ( pParaLevel && ( nRetValue != pParaLevel->mnAdjust ) )
+                rRetValue = rParaLevel.mnAdjust;
+                if ( pParaLevel && ( rRetValue != pParaLevel->mnAdjust ) )
                     bIsHardAttribute = 1;
             }
             break;
             case PPT_ParaAttr_LineFeed :
             {
-                nRetValue = rParaLevel.mnLineFeed;
-                if ( pParaLevel && ( nRetValue != pParaLevel->mnLineFeed ) )
+                rRetValue = rParaLevel.mnLineFeed;
+                if ( pParaLevel && ( rRetValue != pParaLevel->mnLineFeed ) )
                     bIsHardAttribute = 1;
             }
             break;
             case PPT_ParaAttr_UpperDist :
             {
-                nRetValue = rParaLevel.mnUpperDist;
-                if ( pParaLevel && ( nRetValue != pParaLevel->mnUpperDist ) )
+                rRetValue = rParaLevel.mnUpperDist;
+                if ( pParaLevel && ( rRetValue != pParaLevel->mnUpperDist ) )
                     bIsHardAttribute = 1;
             }
             break;
             case PPT_ParaAttr_LowerDist :
             {
-                nRetValue = rParaLevel.mnLowerDist;
-                if ( pParaLevel && ( nRetValue != pParaLevel->mnLowerDist ) )
+                rRetValue = rParaLevel.mnLowerDist;
+                if ( pParaLevel && ( rRetValue != pParaLevel->mnLowerDist ) )
                     bIsHardAttribute = 1;
             }
             break;
             case PPT_ParaAttr_TextOfs :
             {
-                nRetValue = rParaLevel.mnTextOfs;
-                if ( pParaLevel && ( nRetValue != pParaLevel->mnTextOfs ) )
+                rRetValue = rParaLevel.mnTextOfs;
+                if ( pParaLevel && ( rRetValue != pParaLevel->mnTextOfs ) )
                     bIsHardAttribute = 1;
             }
             break;
             case PPT_ParaAttr_BulletOfs :
             {
-                nRetValue = rParaLevel.mnBulletOfs;
-                if ( pParaLevel && ( nRetValue != pParaLevel->mnBulletOfs ) )
+                rRetValue = rParaLevel.mnBulletOfs;
+                if ( pParaLevel && ( rRetValue != pParaLevel->mnBulletOfs ) )
                     bIsHardAttribute = 1;
             }
             break;
             case PPT_ParaAttr_DefaultTab :
             {
-                nRetValue = rParaLevel.mnDefaultTab;
-                if ( pParaLevel && ( nRetValue != pParaLevel->mnDefaultTab ) )
+                rRetValue = rParaLevel.mnDefaultTab;
+                if ( pParaLevel && ( rRetValue != pParaLevel->mnDefaultTab ) )
                     bIsHardAttribute = 1;
             }
             break;
             case PPT_ParaAttr_AsianLB_1 :
             {
-                nRetValue = rParaLevel.mnAsianLineBreak & 1;
-                if ( pParaLevel && ( nRetValue != ( (sal_uInt32)pParaLevel->mnAsianLineBreak & 1 ) ) )
+                rRetValue = rParaLevel.mnAsianLineBreak & 1;
+                if ( pParaLevel && ( rRetValue != ( (sal_uInt32)pParaLevel->mnAsianLineBreak & 1 ) ) )
                     bIsHardAttribute = 1;
             }
             break;
             case PPT_ParaAttr_AsianLB_2 :
             {
-                nRetValue = ( rParaLevel.mnAsianLineBreak >> 1 ) & 1;
-                if ( pParaLevel && ( nRetValue != ( ( (sal_uInt32)pParaLevel->mnAsianLineBreak >> 1 ) & 1 ) ) )
+                rRetValue = ( rParaLevel.mnAsianLineBreak >> 1 ) & 1;
+                if ( pParaLevel && ( rRetValue != ( ( (sal_uInt32)pParaLevel->mnAsianLineBreak >> 1 ) & 1 ) ) )
                     bIsHardAttribute = 1;
             }
             break;
             case PPT_ParaAttr_AsianLB_3 :
             {
-                nRetValue = ( rParaLevel.mnAsianLineBreak >> 2 ) & 1;
-                if ( pParaLevel && ( nRetValue != ( ( (sal_uInt32)pParaLevel->mnAsianLineBreak >> 2 ) & 1 ) ) )
+                rRetValue = ( rParaLevel.mnAsianLineBreak >> 2 ) & 1;
+                if ( pParaLevel && ( rRetValue != ( ( (sal_uInt32)pParaLevel->mnAsianLineBreak >> 2 ) & 1 ) ) )
                     bIsHardAttribute = 1;
             }
             break;
             case PPT_ParaAttr_BiDi :
             {
-                nRetValue = rParaLevel.mnBiDi;
-                if ( pParaLevel && ( nRetValue != pParaLevel->mnBiDi ) )
+                rRetValue = rParaLevel.mnBiDi;
+                if ( pParaLevel && ( rRetValue != pParaLevel->mnBiDi ) )
                     bIsHardAttribute = 1;
             }
             break;
commit 951a9aa2f0aa48fe13da0c4377daa45840db9fc3
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Wed Jan 29 09:43:29 2014 +0000

    remove explicit AdjustLayout calls post .ui-ification
    
    Change-Id: Iab4e3b661d99d1a84b1d11853d1abdf28436d895

diff --git a/dbaccess/source/ui/dlg/advancedsettings.cxx b/dbaccess/source/ui/dlg/advancedsettings.cxx
index fcc0bf2..68c552c 100644
--- a/dbaccess/source/ui/dlg/advancedsettings.cxx
+++ b/dbaccess/source/ui/dlg/advancedsettings.cxx
@@ -494,7 +494,6 @@ namespace dbaui
         static_cast<OGenericAdministrationPage&>(_rPage).SetServiceFactory( getORB() );
         static_cast<OGenericAdministrationPage&>(_rPage).SetAdminDialog(this,this);
 
-        AdjustLayout();
         Window *pWin = GetViewWindow();
         if(pWin)
             pWin->Invalidate();
diff --git a/dbaccess/source/ui/dlg/dbadmin.cxx b/dbaccess/source/ui/dlg/dbadmin.cxx
index a048bd2..63f7424 100644
--- a/dbaccess/source/ui/dlg/dbadmin.cxx
+++ b/dbaccess/source/ui/dlg/dbadmin.cxx
@@ -86,7 +86,6 @@ void ODbAdminDialog::PageCreated(sal_uInt16 _nId, SfxTabPage& _rPage)
     static_cast<OGenericAdministrationPage&>(_rPage).SetServiceFactory( getORB() );
     static_cast<OGenericAdministrationPage&>(_rPage).SetAdminDialog(this,this);
 
-    AdjustLayout();
     Window *pWin = GetViewWindow();
     if(pWin)
         pWin->Invalidate();
commit 744c6ac9aed9deb61e43f702838fdb3688b9c831
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Wed Jan 29 09:40:58 2014 +0000

    convert database properties dialog .to ui
    
    Change-Id: I63c046f1637248e274698dbe13130124669e0712

diff --git a/dbaccess/UIConfig_dbaccess.mk b/dbaccess/UIConfig_dbaccess.mk
index bb77efa..62f3f3b 100644
--- a/dbaccess/UIConfig_dbaccess.mk
+++ b/dbaccess/UIConfig_dbaccess.mk
@@ -10,6 +10,7 @@
 $(eval $(call gb_UIConfig_UIConfig,dbaccess))
 
 $(eval $(call gb_UIConfig_add_uifiles,dbaccess, \
+    dbaccess/uiconfig/ui/admindialog \
     dbaccess/uiconfig/ui/advancedsettingsdialog \
     dbaccess/uiconfig/ui/colwidthdialog \
     dbaccess/uiconfig/ui/directsqldialog  \
diff --git a/dbaccess/inc/dbaccess_helpid.hrc b/dbaccess/inc/dbaccess_helpid.hrc
index b8d3523..0204cdb 100644
--- a/dbaccess/inc/dbaccess_helpid.hrc
+++ b/dbaccess/inc/dbaccess_helpid.hrc
@@ -31,8 +31,6 @@
 #define UID_CTL_CONTENT                                   "DBACCESS_UID_CTL_CONTENT"
 #define HID_TLB_TABBROWSER                                "DBACCESS_HID_TLB_TABBROWSER"
 #define HID_TLB_TREELISTBOX                               "DBACCESS_HID_TLB_TREELISTBOX"
-#define HID_DSADMIN_DIALOG                                "DBACCESS_HID_DSADMIN_DIALOG"
-
 
 #define HID_DSADMIN_PAGE_GENERAL                          "DBACCESS_HID_DSADMIN_PAGE_GENERAL"
 #define HID_DSADMIN_PAGE_DBASE                            "DBACCESS_HID_DSADMIN_PAGE_DBASE"
diff --git a/dbaccess/source/ui/dlg/dbadmin.src b/dbaccess/source/ui/dlg/dbadmin.src
index 8f88911..b4de71b 100644
--- a/dbaccess/source/ui/dlg/dbadmin.src
+++ b/dbaccess/source/ui/dlg/dbadmin.src
@@ -78,23 +78,6 @@
     };
 //-------------------------------------------------------------------------
 
-TabDialog DLG_DATABASE_ADMINISTRATION
-{
-    OutputSize = TRUE ;
-    SVLook = TRUE ;
-    Moveable = TRUE ;
-    Closeable = TRUE ;
-    Hide = TRUE;
-    HelpId = HID_DSADMIN_DIALOG;
-
-    TabControl 1
-    {
-        OutputSize = TRUE ;
-    };
-
-    Text [ en-US ] = "Database properties" ;
-};
-
 ModalDialog DLG_DATABASE_TYPE_CHANGE
 {
     OutputSize = TRUE ;
diff --git a/dbaccess/source/ui/inc/dbu_resource.hrc b/dbaccess/source/ui/inc/dbu_resource.hrc
index a832328..7ca4ee7 100644
--- a/dbaccess/source/ui/inc/dbu_resource.hrc
+++ b/dbaccess/source/ui/inc/dbu_resource.hrc
@@ -76,7 +76,6 @@
 //========================================================================
 // dialog ids
 
-#define DLG_DATABASE_ADMINISTRATION     RID_DIALOG_START +  0
 #define DLG_DBASE_INDEXES               RID_DIALOG_START +  1
 #define DLG_SQLEXCEPTIONCHAIN           RID_DIALOG_START +  3
 #define DLG_DATASOURCE_SELECTION        RID_DIALOG_START +  4
diff --git a/dbaccess/uiconfig/ui/admindialog.ui b/dbaccess/uiconfig/ui/admindialog.ui
new file mode 100644
index 0000000..53e1a0a
--- /dev/null
+++ b/dbaccess/uiconfig/ui/admindialog.ui
@@ -0,0 +1,106 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!-- Generated with glade 3.16.0 on Wed Jan 29 09:37:35 2014 -->
+<interface>
+  <!-- interface-requires gtk+ 3.0 -->
+  <object class="GtkDialog" id="AdminDialog">
+    <property name="can_focus">False</property>
+    <property name="border_width">6</property>
+    <property name="title" translatable="yes">Database properties</property>
+    <property name="type_hint">dialog</property>
+    <child internal-child="vbox">
+      <object class="GtkBox" id="dialog-vbox1">
+        <property name="can_focus">False</property>
+        <property name="orientation">vertical</property>
+        <property name="spacing">12</property>
+        <child internal-child="action_area">
+          <object class="GtkButtonBox" id="dialog-action_area1">
+            <property name="can_focus">False</property>
+            <property name="layout_style">end</property>
+            <child>
+              <object class="GtkButton" id="ok">
+                <property name="label">gtk-ok</property>
+                <property name="visible">True</property>
+                <property name="can_focus">True</property>
+                <property name="can_default">True</property>
+                <property name="has_default">True</property>
+                <property name="receives_default">True</property>
+                <property name="use_stock">True</property>
+              </object>
+              <packing>
+                <property name="expand">False</property>
+                <property name="fill">True</property>
+                <property name="position">0</property>
+              </packing>
+            </child>
+            <child>
+              <object class="GtkButton" id="cancel">
+                <property name="label">gtk-cancel</property>
+                <property name="visible">True</property>
+                <property name="can_focus">True</property>
+                <property name="receives_default">True</property>
+                <property name="use_stock">True</property>
+              </object>
+              <packing>
+                <property name="expand">False</property>
+                <property name="fill">True</property>
+                <property name="position">1</property>
+              </packing>
+            </child>
+            <child>
+              <object class="GtkButton" id="help">
+                <property name="label">gtk-help</property>
+                <property name="visible">True</property>
+                <property name="can_focus">True</property>
+                <property name="receives_default">True</property>
+                <property name="use_stock">True</property>
+              </object>
+              <packing>
+                <property name="expand">False</property>
+                <property name="fill">True</property>
+                <property name="position">2</property>
+              </packing>
+            </child>
+          </object>
+          <packing>
+            <property name="expand">False</property>
+            <property name="fill">True</property>
+            <property name="pack_type">end</property>
+            <property name="position">0</property>
+          </packing>
+        </child>
+        <child>
+          <object class="GtkNotebook" id="tabcontrol">
+            <property name="visible">True</property>
+            <property name="can_focus">False</property>
+            <property name="hexpand">True</property>
+            <property name="vexpand">True</property>
+            <child>
+              <placeholder/>
+            </child>
+            <child type="tab">
+              <object class="GtkLabel" id="advanced">
+                <property name="visible">True</property>
+                <property name="can_focus">False</property>
+                <property name="xalign">0.4699999988079071</property>
+                <property name="label" translatable="yes">Advanced Properties</property>
+              </object>
+              <packing>
+                <property name="tab_fill">False</property>
+              </packing>
+            </child>
+          </object>
+          <packing>
+            <property name="expand">False</property>
+            <property name="fill">True</property>
+            <property name="position">1</property>
+          </packing>
+        </child>
+      </object>
+    </child>
+    <action-widgets>
+      <action-widget response="0">ok</action-widget>
+      <action-widget response="0">cancel</action-widget>
+      <action-widget response="0">help</action-widget>
+    </action-widgets>
+  </object>
+</interface>
commit 4f5dfad645e476792214c4d5c80624d858ee8e78
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Wed Jan 29 09:32:52 2014 +0000

    coverity#1158232 Resource leak
    
    Change-Id: I0e9236a844ac912bd421ce505df1eaeb9b46aefb

diff --git a/sc/qa/unit/ucalc_formula.cxx b/sc/qa/unit/ucalc_formula.cxx
index b19afdc..565c576 100644
--- a/sc/qa/unit/ucalc_formula.cxx
+++ b/sc/qa/unit/ucalc_formula.cxx
@@ -101,7 +101,9 @@ void Test::testFormulaCreateStringFromTokens()
         ScDBData* pData = new ScDBData(
             OUString::createFromAscii(
                 aDBs[i].pName), aDBs[i].nTab, aDBs[i].nCol1, aDBs[i].nRow1, aDBs[i].nCol2,aDBs[i].nRow2);
-        pDBs->getNamedDBs().insert(pData);
+        bool bInserted = pDBs->getNamedDBs().insert(pData);
+        if (!bInserted)
+            delete pData;
     }
 
     const char* aTests[] = {
commit 681cc3d13ec96d5d796f46d343ae8b06780fd121
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Wed Jan 29 09:30:04 2014 +0000

    coverity#1158237 Resource leak
    
    Change-Id: I2204ec36344b8f7662efa8aed31e9363bb791616

diff --git a/desktop/source/lib/shim.c b/desktop/source/lib/shim.c
index c821d2d..7115c6e 100644
--- a/desktop/source/lib/shim.c
+++ b/desktop/source/lib/shim.c
@@ -53,6 +53,7 @@ SAL_DLLPUBLIC_EXPORT LibreOffice *lo_init( const char *install_path )
     pSym = (HookFunction *) dlsym( dlhandle, "liblibreoffice_hook" );
     if( !pSym ) {
         fprintf( stderr, "failed to find hook in library '%s'\n", imp_lib );
+        dlclose( dlhandle );
         free( imp_lib );
         return NULL;
     }
commit a251d3593a3e7cd11b633791123db522dffa5a55
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Wed Jan 29 09:28:40 2014 +0000

    missed a non-local STR_PAGETITLE_CONNECTION conversion
    
    Change-Id: If711a458aa5c099621e4833117985d111a8f8d05

diff --git a/dbaccess/source/ui/dlg/dbwizsetup.cxx b/dbaccess/source/ui/dlg/dbwizsetup.cxx
index 2cc4d58..db85512 100644
--- a/dbaccess/source/ui/dlg/dbwizsetup.cxx
+++ b/dbaccess/source/ui/dlg/dbwizsetup.cxx
@@ -258,10 +258,7 @@ OUString ODbTypeWizDialogSetup::getStateDisplayName( WizardState _nState ) const
             sRoadmapItem = m_sRM_AuthentificationText;
             break;
         case PAGE_DBSETUPWIZARD_USERDEFINED:
-            {
-                LocalResourceAccess aDummy(DLG_DATABASE_ADMINISTRATION, RSC_TABDIALOG);
-                sRoadmapItem = ModuleRes(STR_PAGETITLE_CONNECTION);
-            }
+            sRoadmapItem = ModuleRes(STR_PAGETITLE_CONNECTION);
             break;
         case PAGE_DBSETUPWIZARD_FINAL:
             sRoadmapItem = m_sRM_FinalText;


More information about the Libreoffice-commits mailing list
diff --git a/dbaccess/source/ui/dlg/dbadmin.cxx b/dbaccess/source/ui/dlg/dbadmin.cxx
index 6102c28..a048bd2 100644
--- a/dbaccess/source/ui/dlg/dbadmin.cxx
+++ b/dbaccess/source/ui/dlg/dbadmin.cxx
@@ -50,23 +50,19 @@ using namespace com::sun::star::container;
 // ODbAdminDialog
 ODbAdminDialog::ODbAdminDialog(Window* _pParent
                                , SfxItemSet* _pItems
-                               , const Reference< XComponentContext >& _rxContext
-                               )
-    :SfxTabDialog(_pParent, ModuleRes(DLG_DATABASE_ADMINISTRATION), _pItems)
-    ,m_bApplied(sal_False)
-    ,m_bUIEnabled( sal_True )
-    ,m_nMainPageID( PAGE_CONNECTION )
+                               , const Reference< XComponentContext >& _rxContext)
+    : SfxTabDialog(_pParent, "AdminDialog",
+        "dbaccess/ui/admindialog.ui", _pItems)
+    , m_bApplied(false)
+    , m_bUIEnabled(true)
 {
-
     m_pImpl.reset(new ODbDataSourceAdministrationHelper(_rxContext,this,this));
 
     // add the initial tab page
-    AddTabPage( m_nMainPageID, OUString( ModuleRes( STR_PAGETITLE_GENERAL ) ), OConnectionTabPage::Create, NULL );
+    m_nMainPageID = AddTabPage("advanced", OConnectionTabPage::Create, NULL);
 
     // remove the reset button - it's meaning is much too ambiguous in this dialog
     RemoveResetButton();
-    // no local resources needed anymore
-    FreeResource();
 }
 
 ODbAdminDialog::~ODbAdminDialog()
@@ -200,14 +196,14 @@ void ODbAdminDialog::impl_resetPages(const Reference< XPropertySet >& _rxDatasou
     delete pExampleSet;
     pExampleSet = new SfxItemSet(*GetInputSetImpl());
 
     // special case: MySQL Native does not have the generic PAGE_CONNECTION page
 
     DbuTypeCollectionItem* pCollectionItem = PTR_CAST(DbuTypeCollectionItem, getOutputSet()->GetItem(DSID_TYPECOLLECTION));
     ::dbaccess::ODsnTypeCollection* pCollection = pCollectionItem->getCollection();
     if ( pCollection->determineType(getDatasourceType( *pExampleSet )) == ::dbaccess::DST_MYSQL_NATIVE )
     {
         AddTabPage( PAGE_MYSQL_NATIVE, OUString( ModuleRes( STR_PAGETITLE_CONNECTION ) ), ODriversSettings::CreateMySQLNATIVE, NULL );
-        RemoveTabPage( PAGE_CONNECTION );
+        RemoveTabPage("advanced");
         m_nMainPageID = PAGE_MYSQL_NATIVE;
     }
 
@@ -200,14 +196,14 @@ void ODbAdminDialog::impl_resetPages(const Reference< XPropertySet >& _rxDatasou
     pExampleSet = new SfxItemSet(*GetInputSetImpl());
 
-    // special case: MySQL Native does not have the generic PAGE_CONNECTION page
+    // special case: MySQL Native does not have the generic "advanced" page
 
     DbuTypeCollectionItem* pCollectionItem = PTR_CAST(DbuTypeCollectionItem, getOutputSet()->GetItem(DSID_TYPECOLLECTION));